@@ -1,7 +1,7 @@
-from db import db
+from ext import EXT_CONTEXT
 from sqlalchemy import Column, Integer, String
 
-class User(db.Model):
+class User(EXT_CONTEXT["db"].Model):
 
     __tablename__ = 'user'
 
